/*
 * Copyright (c) 2005 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* $LAAS$ */

#include <math.h>
#include <pthread.h>

#include <portLib.h>

#include <neobotix/pscan.h>
#include <neobotix/neo.h>
#include <neobotix/canMotors.h>

#include "driveParam.h"

/*----------------------------------------------------------------------*/

/*
 * Init drive parameters
 */
void
driveParamInit(CAN_DRIVE_PARAMS *p, int ident)
{
	p->driveIdent = ident;
	p->encIncrPerRevMot = DRIVE_PARAM_ENC_INCR_PER_REV_MOT;
	p->gearRatio = DRIVE_PARAM_GEAR_RATIO;
	p->sign = DRIVE_PARAM_SIGN;
	p->velMaxEncIncrS = DRIVE_PARAMS_VEL_MAX_ENC_INCR_S;
	p->posGearRadToPosMotIncr = p->encIncrPerRevMot * p->gearRatio 
	    / (2.0 * M_PI);
}

/*----------------------------------------------------------------------*/

/*
 * Convert position and velocity from Radian (per second) to
 * increments (per period) respectively
 */
void
driveParamPosVelRadToIncr(CAN_DRIVE_PARAMS *p, double posRad, double velRadS,
    int *pPosIncr, int *pVelIncrPeriod)
{
	*pPosIncr = driveParamPosGearRadToPosMotIncr(p, posRad);
	*pVelIncrPeriod = driveParamVelGearRadSToVelMotIncrPeriod(p, velRadS);
}

/*----------------------------------------------------------------------*/
/*
 * Converts position from Radians to increments
 */
int 
driveParamPosGearRadToPosMotIncr(CAN_DRIVE_PARAMS *p, double posGearRad)
{
	return ((int)(posGearRad * p->posGearRadToPosMotIncr));
}

/*----------------------------------------------------------------------*/
/*
 * Converts position from increments to Radians 
 */
double
driveParamPosMotIncrToPosGearRad(CAN_DRIVE_PARAMS *p, int posIncr)
{
	return ((double)posIncr / p->posGearRadToPosMotIncr);
}
/*----------------------------------------------------------------------*/
/*
 * Convert a velocity from Radian/second to increments/period
 */
int
driveParamVelGearRadSToVelMotIncrPeriod(CAN_DRIVE_PARAMS *p, 
    double velGearRadS)
{
	return ((int)(velGearRadS * p->posGearRadToPosMotIncr));
}
/*----------------------------------------------------------------------*/
/* 
 * Convert a velocity from increments/period to Radian/second
 */
double 
driveParamVelMotIncrPeriodToVelGearRadS(CAN_DRIVE_PARAMS *p, 
    int velMotIncrPeriod)
{
	return ((double)velMotIncrPeriod / p->posGearRadToPosMotIncr);
}
