/*
 * Copyright (c) 2006 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ident "$Id$"

#include <stdio.h>
#include <stdlib.h>

#include <errnoLib.h>
#include <portLib.h>

#include "neobotix/pscanErrors.h"
#include "neobotix/canMotorsErrors.h"
#include "neobotix/canGyroErrors.h"
#include "neobotix/canIOErrors.h"
#include "neobotix/canUSErrors.h"
#include "neobotix/neoErrors.h"

#include "neobotix/neobotixErrors.h"

static const H2_ERROR const pscanH2errMsgs[]     = PSCAN_H2_ERR_MSGS;
static const H2_ERROR const canGyroH2errMsgs[]   = CANGYRO_H2_ERR_MSGS;
static const H2_ERROR const canMotorsH2errMsgs[] = CANMOTORS_H2_ERR_MSGS;
static const H2_ERROR const canIOH2errMsgs[]     = CANIO_H2_ERR_MSGS;
static const H2_ERROR const canUSH2errMsgs[]     = CANUS_H2_ERR_MSGS;
static const H2_ERROR const neoH2errMsgs[]       = NEO_H2_ERR_MSGS;

int neobotixRecordH2errMsgs(void)
{
  /* pscan errors */
  if (!h2recordErrMsgs("pscanRecordH2errMsgs", "pscan", M_pscanLib, 
		      sizeof(pscanH2errMsgs)/sizeof(H2_ERROR),
		      pscanH2errMsgs))
    return 0;

  /* canGyro errors */
  if (!h2recordErrMsgs("canGyroRecordH2errMsgs", "canGyro", M_canGyro, 
		       sizeof(canGyroH2errMsgs)/sizeof(H2_ERROR),
		       canGyroH2errMsgs))
    return 0;

  /* canMotors errors */
  if (!h2recordErrMsgs("canMotorsRecordH2errMsgs", "canMotors", M_canMotorsLib, 
		       sizeof(canMotorsH2errMsgs)/sizeof(H2_ERROR),
		       canMotorsH2errMsgs))
    return 0;

  /* canIO errors */
  if (!h2recordErrMsgs("canIORecordH2errMsgs", "canIO", M_canIoLib, 
		       sizeof(canIOH2errMsgs)/sizeof(H2_ERROR),
		       canIOH2errMsgs))
    return 0;

  /* canUS errors */
  if (!h2recordErrMsgs("canUSRecordH2errMsgs", "canUS", M_canUsLib, 
		       sizeof(canUSH2errMsgs)/sizeof(H2_ERROR),
		       canUSH2errMsgs))
    return 0;
  
  /* neo errors */
  if (!h2recordErrMsgs("neoRecordH2errMsgs", "neo", M_neoLib, 
		       sizeof(neoH2errMsgs)/sizeof(H2_ERROR),
		       neoH2errMsgs))
    return 0;

  return 1;
}
